@@ -60,10 +60,12 @@
 #' suppressWarnings()
 #'
 #' @importFrom caret confusionMatrix sensitivity specificity
-#' @importFrom pROC roc
+#' @importFrom pROC roc auc
+#' @importFrom stats quantile
+#' @importFrom ecospat ecospat.boyce
 #'
 #' @export
-summary_sdm <- function (data, lev = NULL, model = NULL, custom_fun=NULL) {
+summary_sdm <- function(data, lev = NULL, model = NULL, custom_fun = NULL) {
   if (length(lev) > 2) {
     stop(paste("Your outcome has", length(lev), "levels. The summary function isn't appropriate."))
   }
@@ -71,38 +73,93 @@ summary_sdm <- function (data, lev = NULL, model = NULL, custom_fun=NULL) {
     stop("levels of observed and predicted data do not match")
   }
 
-  rocObject <- try(pROC::roc(data$obs,
-                             data[, lev[1]],
-                             direction = ">",
-                             quiet = TRUE),
-                   silent = TRUE)
+  # ROC and AUC
+  rocObject <- try(pROC::roc(data$obs, data[, lev[1]],
+                             direction = ">", quiet = TRUE), silent = TRUE)
   rocAUC <- if(inherits(rocObject, "try-error")) NA else rocObject$auc
 
-  cm = caret::confusionMatrix(data$pred, data$obs)
+  # Confusion matrix metrics
+  cm <- caret::confusionMatrix(data$pred, data$obs)
   mets <- cm$overall |> round(3)
   mets_class <- cm$byClass |> round(3)
 
-  TP = cm$table[1,1]
-  FP = cm$table[2,1]
-  TN = cm$table[2,2]
-  FN = cm$table[1,2]
+  TP <- cm$table[1, 1]
+  FP <- cm$table[2, 1]
+  TN <- cm$table[2, 2]
+  FN <- cm$table[1, 2]
+
+  # Convert observations to numeric (1 for presence/first level, 0 for absence/second level)
+  obs_num <- ifelse(data$obs == lev[1], 1, 0)
+  pred_prob <- data[, lev[1]]
+
+  # Continuous Boyce Index using ecospat
+  cbi <- tryCatch({
+    # ecospat.boyce expects: fit (predicted values for all data),
+    # obs (predicted values for presences only)
+    presence_idx <- obs_num == 1
+    boyce_result <- ecospat::ecospat.boyce(
+      fit = pred_prob,
+      obs = pred_prob[presence_idx],
+      nclass = 0,  # Use quantiles
+      window.w = "default",
+      res = 100,
+      PEplot = FALSE
+    )
+    round(boyce_result$cor, 3)
+  }, error = function(e) {
+    NA
+  })
+
+  # Partial ROC using pROC package
+  partial_roc <- tryCatch({
+    # Calculate partial AUC from 100% to 90% specificity (or 0 to 10% FPR)
+    # This is equivalent to allowing 10% omission error
+    roc_obj <- pROC::roc(obs_num, pred_prob, direction = ">", quiet = TRUE)
+
+    # Partial AUC with specificity from 0.9 to 1.0
+    p_auc <- pROC::auc(roc_obj, partial.auc = c(1, 0.9),
+                       partial.auc.focus = "specificity",
+                       partial.auc.correct = TRUE)
+
+    round(as.numeric(p_auc), 3)
+  }, error = function(e) {
+    NA
+  })
+
+  # Omission rate at 10th percentile threshold
+  omission_10 <- tryCatch({
+    presence_probs <- pred_prob[obs_num == 1]
+    threshold <- stats::quantile(presence_probs, probs = 0.10, na.rm = TRUE)
+    omitted <- sum(presence_probs < threshold, na.rm = TRUE)
+    total_presences <- sum(obs_num == 1)
+    round(omitted / total_presences, 3)
+  }, error = function(e) {
+    NA
+  })
+
   if(length(lev) > 1) {
-    sens = caret::sensitivity(data[, "pred"], data[, "obs"], lev[1])
-    spec = caret::specificity(data[, "pred"], data[, "obs"], lev[2])
-    P = as.numeric(table(data$obs)[lev[1]])
-    N = as.numeric(table(data$obs)[lev[2]])
-    out <- c(rocAUC, sens+spec-1, mets_class, mets, P, N, TP, FP, TN, FN)
+    sens <- caret::sensitivity(data[, "pred"], data[, "obs"], lev[1])
+    spec <- caret::specificity(data[, "pred"], data[, "obs"], lev[2])
+    P <- as.numeric(table(data$obs)[lev[1]])
+    N <- as.numeric(table(data$obs)[lev[2]])
+
+    out <- c(rocAUC, sens + spec - 1, mets_class, mets,
+             P, N, TP, FP, TN, FN, cbi, partial_roc, omission_10)
     names(out) <- c("ROC", "TSS", names(mets_class), names(mets), "Positive", "Negative",
-                    "True Positive", "False Positive", "True Negative", "False Negative")
+                    "True Positive", "False Positive", "True Negative", "False Negative", "CBI", "pAUC", "Omission_10pct")
   } else {
-    out <- c(rocAUC, mets_class, mets, TP, FP, TN, FN)
-    names(out) <- c("ROC", names(mets_class), names(mets),
-                    "True Positive", "False Positive", "True Negative", "False Negative")
+    out <- c(rocAUC, mets_class, mets,
+             TP, FP, TN, FN, cbi, partial_roc, omission_10)
+    names(out) <- c("ROC",names(mets_class), names(mets),
+                    "True Positive", "False Positive", "True Negative", "False Negative", "CBI", "pAUC", "Omission_10pct")
   }
 
   return(out)
 }
 
+
+
+
 #' @rdname summary_sdm
 #' @export
 summary_sdm_presence_only <- function(data, lev, threshold) {
